@@ -85,7 +85,7 @@ if (($form = data_submitted()) && (confirm_sesskey())) {
         $basedir = opendir($base);
         while ($file = readdir($basedir)) {
             $path = $base.'/'.$file;
-            if (filetype($path) === 'file' and preg_match($htmlpat, $file)) {
+            if (filetype($path) == 'file' and preg_match($htmlpat, $file)) {
                 $refs[] = str_replace($coursebase, '', $path);
             }
         }
