@@ -1,4 +1,4 @@
-<?PHP // $Id: restorelib.php,v 1.4 2005/07/14 20:58:08 skodak Exp $
+<?PHP // $Id$
     //This php script contains all the stuff to backup/restore
     //book mods
 
@@ -53,7 +53,9 @@
             $newid = insert_record ('book',$book);
 
             //Do some output
-            echo '<ul><li>'.get_string('modulename','book').' "'.$book->name.'"<br>';
+            if (!defined('RESTORE_SILENTLY')) {
+                echo '<ul><li>'.get_string('modulename','book').' "'.$book->name.'"<br>';
+            }
             backup_flush(300);
 
             if ($newid) {
@@ -67,7 +69,9 @@
                 $status = false;
             }
             //Finalize ul
-            echo "</ul>";
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "</ul>";
+            }
 
         } else {
             $status = false;
@@ -112,9 +116,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo '.';
-                if (($i+1) % 1000 == 0) {
-                    echo '<br>';
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo '.';
+                    if (($i+1) % 1000 == 0) {
+                        echo '<br>';
+                    }
                 }
                 backup_flush(300);
             }
@@ -184,7 +190,9 @@
                 }
                 break;
             default:
-                echo "action (".$log->module."-".$log->action.") unknow. Not restored<br>";                 //Debug
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo "action (".$log->module."-".$log->action.") unknown. Not restored<br>";                 //Debug
+                }
                 break;
         }
 
@@ -311,14 +319,18 @@
                     $book->summary = addslashes($result);
                     $status = update_record('book',$book);
                     if ($CFG->debug>7) {
-                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                        if (!defined('RESTORE_SILENTLY')) {
+                            echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                        }
                     }
                 }
                 //Do some output
                 if (($i+1) % 5 == 0) {
-                    echo '.';
-                    if (($i+1) % 100 == 0) {
-                        echo '<br />';
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo '.';
+                        if (($i+1) % 100 == 0) {
+                            echo '<br />';
+                        }
                     }
                     backup_flush(300);
                 }
@@ -343,14 +355,18 @@
                     $chapter->content = addslashes($result);
                     $status = update_record('book_chapters',$chapter);
                     if ($CFG->debug>7) {
-                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                        if (!defined('RESTORE_SILENTLY')) {
+                            echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                        }
                     }
                 }
                 //Do some output
                 if (($i+1) % 5 == 0) {
-                    echo '.';
-                    if (($i+1) % 100 == 0) {
-                        echo '<br />';
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo '.';
+                        if (($i+1) % 100 == 0) {
+                            echo '<br />';
+                        }
                     }
                     backup_flush(300);
                 }
