@@ -18,7 +18,7 @@ if (!$chapter->subchapter) {
     $chapters = get_records('book_chapters', 'bookid', $book->id, 'pagenum', 'id, subchapter, hidden');
     $found = 0;
     foreach($chapters as $ch) {
-        if ($ch->id === $chapter->id) {
+        if ($ch->id == $chapter->id) {
             $found = 1;
         } else if ($found and $ch->subchapter) {
             $ch->hidden = $chapter->hidden;
