@@ -226,7 +226,7 @@ $doimport = ($isteacher and $edit) ? '<font size="-1"> (<a href="import.php?id='
         $content = '';
         if (!$book->customtitles) {
           if ($currsubtitle == '&nbsp;') {
-              $content .= '<p class="book_chapter_title">'.$currtitle.'<p>';
+              $content .= '<p class="book_chapter_title">'.$currtitle.'</p>';
           } else {
               $content .= '<p class="book_chapter_title">'.$currtitle.'<br />'.$currsubtitle.'</p>';
           }
